==> ui-18.0.1.tgz: package/components/card/Card.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { getClassName } from '@react-devui/utils';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DSeparator } from '../separator';
import { DCardContent } from './CardContent';
import { DCardHeader } from './CardHeader';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCard' });
export const DCard = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dBorder = true, dShadow = false, dActions } = _a, restProps = __rest(_a, ["children", "dBorder", "dShadow", "dActions"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}card`, {
            [`${dPrefix}card--border`]: dBorder,
            [`${dPrefix}card--shadow`]: dShadow === true,
            [`${dPrefix}card--shadow-hover`]: dShadow === 'hover',
        }) }, { children: [children, dActions && (_jsx("div", Object.assign({ className: `${dPrefix}card__actions` }, { children: React.Children.map(dActions, (action, index) => (_jsxs(_Fragment, { children: [React.cloneElement(action, {
                            className: getClassName(action.props.className, `${dPrefix}card__action`),
                        }), index !== dActions.length - 1 && _jsx(DSeparator, { style: { margin: 8 }, dVertical: true })] }))) })))] })));
};
DCard.Header = DCardHeader;
DCard.Content = DCardContent;

==> ui-18.3.5.tgz: package/components/card/Card.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import { getClassName } from '@react-devui/utils';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DSeparator } from '../separator';
import { DCardAction } from './CardAction';
import { DCardContent } from './CardContent';
import { DCardHeader } from './CardHeader';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DCard' });
export const DCard = (props) => {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dBorder = true, dShadow = false, dActions } = _a, restProps = __rest(_a, ["children", "dBorder", "dShadow", "dActions"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    return (_jsxs("div", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}card`, {
            [`${dPrefix}card--border`]: dBorder,
            [`${dPrefix}card--shadow`]: dShadow === true,
            [`${dPrefix}card--shadow-hover`]: dShadow === 'hover',
        }) }, { children: [children, dActions && (_jsx("div", Object.assign({ className: `${dPrefix}card__actions` }, { children: React.Children.map(dActions, (action, index) => (_jsxs(_Fragment, { children: [action, index !== dActions.length - 1 && _jsx(DSeparator, { style: { margin: 8 }, dVertical: true })] }))) })))] })));
};
DCard.Action = DCardAction;
DCard.Header = DCardHeader;
DCard.Content = DCardContent;
